@@ -5,7 +5,6 @@ Created on Mon Mar 15 16:21:43 2021
 
 @author: mirazoki
 """
-from _ast import Try
 import datetime
 import glob
 import itertools
@@ -107,6 +106,9 @@ def coast_water_level_process(region, tsdir, outdir, label, maskdir, swashtype='
     # make stnames the stations coordinate
     datamodel = datamodel.assign_coords(stations=datamodel['stnames'].values)
 
+    if not isinstance(datamodel.indexes['time'][0],datetime.datetime):
+        datamodel=datamodel.assign_coords(time=datamodel.indexes['time'].to_datetimeindex()) 
+
     encodingspec = dict()
     # check if other elements need loading up
     if fes_tide is not None:
@@ -175,7 +177,8 @@ def coast_water_level_process(region, tsdir, outdir, label, maskdir, swashtype='
             _, index = np.unique(datamodel['time'], return_index=True)
             datamodel = datamodel.isel(time=index)
 
-            xrtwl = datamodel['zos'] + toceaninterp.interp(time=datamodel['time'])  # maybe I need to interpolate to common times?
+            #xrtwl = datamodel['zos'] + toceaninterp.interp(time=datamodel['time'])  # maybe I need to interpolate to common times?
+            xrtwl = datamodel['zos'].interp(time=toceaninterp['time']) + toceaninterp  # maybe I need to interpolate to common times?
             datamodel['zos'] = xrtwl
 
     # make unique
@@ -195,14 +198,23 @@ def coast_water_level_process(region, tsdir, outdir, label, maskdir, swashtype='
     datamodel['zos']=temp
     # add wave contributions
     # initialize
-    datasetup_xr = xr.DataArray(
-        data=np.zeros(datamodel['zos'].shape),  # initialize to zero
-        dims=datamodel.dims,
-        coords=datamodel.coords,
-        attrs={'standard_name': 'wave_setup',
-                'units':'m'}
-        )
-
+    try:
+        datasetup_xr = xr.DataArray(
+            data=np.zeros(datamodel['zos'].shape),  # initialize to zero
+            dims=datamodel.dims,
+            coords=datamodel.coords,
+            attrs={'standard_name': 'wave_setup',
+                    'units':'m'}
+            )
+    except:
+        datasetup_xr = xr.DataArray(
+            data=np.zeros(datamodel['zos'].shape).T,  # initialize to zero
+            dims=datamodel.dims,
+            coords=datamodel.coords,
+            attrs={'standard_name': 'wave_setup',
+                    'units':'m'}
+            )        
+        
     datamodel = datamodel.assign(Vsetup=datasetup_xr.transpose("stations", "time"))
     if swashtype == 'cte':
         eta, _, _, R, irb = sf.Hsprop(datamodel['VHM0'].values)
@@ -216,7 +228,13 @@ def coast_water_level_process(region, tsdir, outdir, label, maskdir, swashtype='
         beta[np.isnan(beta)] = 0.0  # force it to be dissipative,beta independent
         eta, _, _, R, irb = sf.stockdon(datamodel['VHM0'].values,
                                            datamodel['VTPK'].values, beta=beta)
-
+    # print('wl shape:')
+    # print(datamodel['zos'].shape)
+    # print('wave shape:')
+    # print(datamodel['VHM0'].shape)
+    # print('eta shape:')
+    # print(eta.shape)
+    
     datamodel['Vsetup'].values = eta
     datamodel['Vsetup'].attrs['long_name'] = 'wave setup calculated using %s parameterization and %s slope' % (swashtype, betatype)
 
@@ -235,7 +253,7 @@ def coast_water_level_process(region, tsdir, outdir, label, maskdir, swashtype='
     if not os.path.exists(outdir):
         os.mkdir(outdir)
     # write out independent days
-    dayarray = pd.date_range(start=datamodel.indexes['time'][0], end=datamodel.indexes['time'][-1], freq='1D', closed='left')
+    dayarray = pd.date_range(start=datamodel.indexes['time'][0], end=datamodel.indexes['time'][-1], freq='1D', inclusive='left')
     bday = datetime.datetime.strptime(label, '%Y-%m-%d_%H-%M-%S').strftime('%Y%m%d%H%M%S')
     for iday in dayarray:
         tini = iday.to_pydatetime()
