@@ -68,7 +68,7 @@ def execute_workflow(args):
             trgdat = trigg.trigger(outdir, ncdat_fc, maphin, maxdist=maxd)
             trgl.append(trgdat)
             
-            if bool(args.plot):
+            if args.plot is not None:
                 ncdat['stations']=[stname.decode("utf-8").lstrip() for stname in ncdat.isel(time=0)['stations'].values]
                 for idx in trgdat.iloc[np.where(trgdat['flag'])[0]].index[::10]:
                     stn=trgdat.loc[idx]['map_id']
@@ -91,8 +91,7 @@ def main():
     parser = argparse.ArgumentParser("op_trigger")
     parser.add_argument('-c', '--config', metavar='<config_file>', default='ecfas.cfg', required=True, help='Absolute path to config file')
     parser.add_argument('-t', '--t0', metavar='<YYmmdd_HHMMSS>', default=None, help='Start time t0 in the format YYmmdd_HHMMSS')
-    parser.add_argument('-p', '--plot', default=0, help='Switch to plot triggered coastal points')
-    parser.add_argument('--debug', action='store_true', help='Debug mode')
+    parser.add_argument('-p', '--plot', help='Switch to plot triggered coastal points')
 
     execute_workflow(parser.parse_args())
 
