@@ -3,7 +3,7 @@ import logging
 import os
 import sys
 
-from motu_utils import motu_api, utils_log
+from motu_utils import motu_api
 
 import ecfas.cmems_datasets as dsets
 import numpy as np
